@@ -18,7 +18,7 @@
 
 
 
-OSL_NAMESPACE_ENTER
+OSL_NAMESPACE_BEGIN
 
 namespace pvt {  // OSL::pvt
 
@@ -662,4 +662,4 @@ ShadingSystemImpl::LoadMemoryCompiledShader(string_view shadername,
 
 
 };  // namespace pvt
-OSL_NAMESPACE_EXIT
+OSL_NAMESPACE_END
