@@ -12,21 +12,15 @@
 
 using namespace OSL;
 
-OSL_NAMESPACE_ENTER
+OSL_NAMESPACE_BEGIN
 namespace __OSL_WIDE_PVT {
 
 OSL_USING_DATA_WIDTH(__OSL_WIDTH)
 
-// Utility: retrieve a pointer to the ShadingContext's noise params
-// struct, also re-initialize its contents.
-OSL_BATCHOP void*
-__OSL_OP(get_noise_options)(void* bsg_)
+OSL_BATCHOP void
+__OSL_OP(osl_init_noise_options)(void* bsg_, void* opt)
 {
-    auto* bsg = reinterpret_cast<BatchedShaderGlobals*>(bsg_);
-
-    RendererServices::NoiseOpt* opt = bsg->uniform.context->noise_options_ptr();
-    new (opt) RendererServices::NoiseOpt;
-    return opt;
+    new (opt) NoiseParams;
 }
 
 
@@ -41,6 +35,6 @@ __OSL_MASKED_OP(count_noise)(void* bsg_, unsigned int mask_value)
 
 
 }  // namespace __OSL_WIDE_PVT
-OSL_NAMESPACE_EXIT
+OSL_NAMESPACE_END
 
 #include "undef_opname_macros.h"
