@@ -305,6 +305,9 @@ set_shadingsys_options()
         } else if ((!batch_size_requested || batch_size == 8)
                    && shadingsys->configure_batch_execution_at(8)) {
             batch_size = 8;
+        } else if ((!batch_size_requested || batch_size == 4)
+                   && shadingsys->configure_batch_execution_at(4)) {
+            batch_size = 4;
         } else {
             OSL::print(
                 "WARNING:  Hardware or library requirements to utilize batched execution");
@@ -708,8 +711,6 @@ getargs(int argc, const char* argv[])
     ap.arg("filename")
       .hidden()
       .action([&](cspan<const char*> argv){ stash_shader_arg(argv); });
-    ap.arg("--help")
-      .help("Print help message");
     ap.arg("-v", &verbose)
       .help("Verbose messages");
     ap.arg("-t %d:NTHREADS", &num_threads)
@@ -860,16 +861,7 @@ getargs(int argc, const char* argv[])
       .help("journal jbuffer size in MB");
 
     // clang-format on
-    if (ap.parse(argc, argv) < 0) {
-        std::cerr << ap.geterror() << std::endl;
-        ap.usage();
-        exit(EXIT_FAILURE);
-    }
-    if (ap["help"].get<int>()) {
-        ap.usage();
-        print_info();
-        exit(EXIT_SUCCESS);
-    }
+    ap.parse_args(argc, argv);
 }
 
 
@@ -906,7 +898,7 @@ process_shader_setup_args(int argc, const char* argv[])
       .action([&](cspan<const char*> argv){ specify_expr(argv); });
 
     // clang-format on
-    if (ap.parse(argc, argv) < 0
+    if (ap.parse_args(argc, argv) < 0
         || (shadernames.empty() && groupspec.empty())) {
         std::cerr << "ERROR: No shader or group was specified.\n";
         std::cerr << ap.geterror() << std::endl;
@@ -1197,9 +1189,11 @@ setup_output_images(SimpleRenderer* rend, ShadingSystem* shadingsys,
             // jit_group will optimize the group if necesssary
             if (batch_size == 16) {
                 shadingsys->batched<16>().jit_group(shadergroup.get(), ctx);
-            } else {
-                ASSERT((batch_size == 8) && "Unsupported batch size");
+            } else if (batch_size == 8) {
                 shadingsys->batched<8>().jit_group(shadergroup.get(), ctx);
+            } else {
+                OSL_ASSERT((batch_size == 4) && "Unsupported batch size");
+                shadingsys->batched<4>().jit_group(shadergroup.get(), ctx);
             }
         } else
 #endif
@@ -2203,13 +2197,19 @@ test_shade(int argc, const char* argv[])
                             batched_shade_region<16>(rend, shadergroup.get(),
                                                      sub_roi, save);
                         });
-                } else {
-                    ASSERT((batch_size == 8) && "Unsupported batch size");
+                } else if (batch_size == 8) {
                     OIIO::ImageBufAlgo::parallel_image(
                         roi, num_threads, [&](OIIO::ROI sub_roi) -> void {
                             batched_shade_region<8>(rend, shadergroup.get(),
                                                     sub_roi, save);
                         });
+                } else {
+                    OSL_ASSERT((batch_size == 4) && "Unsupported batch size");
+                    OIIO::ImageBufAlgo::parallel_image(
+                        roi, num_threads, [&](OIIO::ROI sub_roi) -> void {
+                            batched_shade_region<4>(rend, shadergroup.get(),
+                                                    sub_roi, save);
+                        });
                 }
             } else
 #    endif
