@@ -4,7 +4,6 @@
 # SPDX-License-Identifier: BSD-3-Clause
 # https://github.com/AcademySoftwareFoundation/OpenShadingLanguage
 
-from __future__ import print_function, absolute_import
 import os
 import glob
 import sys
@@ -79,13 +78,24 @@ test_source_dir = os.getenv('OSL_TESTSUITE_SRC',
 command = ""
 outputs = [ "out.txt" ]    # default
 
-# Control image differencing
+# The image comparison thresholds are tricky to remember. Here's the key:
+# A test fails if more than `failpercent` of pixel values differ by more
+# than `failthresh` AND the difference is more than `failrelative` times the
+# correct pixel value, or if even one pixel differs by more than `hardfail`.
+failthresh = 0.004         # "Failure" threshold for any pixel value
+hardfail = 0.01            # Even one pixel this wrong => hard failure
+failpercent = 0.02         # Ok fo this percentage of pixels to "fail"
+failrelative = 0.001       # Ok to fail up to this amount vs the pixel value
+allowfailures = 0          # Freebie failures
+
+# Some tests are designed for the app running to "fail" (in the sense of
+# terminating with an error return code), for example, a test that is designed
+# to present an error condition to check that it issues the right error. That
+# "failure" is a success of the test! For those cases, set `failureok = 1` to
+# indicate that the app having an error is fine, and the full test will pass
+# or fail based on comparing the output files.
 failureok = 0
-failthresh = 0.004
-hardfail = 0.01
-failpercent = 0.02
-failrelative = 0.001
-allowfailures = 0
+
 idiff_program = "oiiotool"
 idiff_postfilecmd = ""
 skip_diff = int(os.environ.get("OSL_TESTSUITE_SKIP_DIFF", "0"))
@@ -407,6 +417,16 @@ if "DEBUG" in os.environ and os.environ["DEBUG"] :
     hardfail *= 2.0
     failpercent *= 2.0
 
+# Allow an environment variable to scale the testsuite image comparison
+# thresholds:
+if 'OSL_TESTSUITE_THRESH_SCALE' in os.environ :
+    thresh_scale = float(os.getenv('OSL_TESTSUITE_THRESH_SCALE', '1.0'))
+    failthresh *= thresh_scale
+    hardfail *= thresh_scale
+    failpercent *= thresh_scale
+    failrelative *= thresh_scale
+    allowfailures = int(allowfailures * thresh_scale)
+
 # Force out.txt to be in the outputs
 ##if "out.txt" not in outputs :
 ##    outputs.append ("out.txt")
@@ -445,7 +465,7 @@ else :
                    failthresh=failthresh, failpercent=failpercent, filter_re=filter_re)
     
 if ret == 0 and cleanup_on_success :
-    for ext in image_extensions + [ ".txt", ".diff" ] :
+    for ext in image_extensions + [ ".txt", ".diff", ".oso" ] :
         files = glob.iglob (srcdir + '/*' + ext)
         baselineFiles = glob.iglob (srcdir + '/baseline/*' + ext) 
         for f in chain(files,baselineFiles) :
